Name:           jss
Version:        4.2.5
Release:        1%{?dist}
Summary:        Java Security Services (JSS)

Group:          System Environment/Libraries
License:        MPL/GPL/LGPL
URL:            http://www.mozilla.org/projects/security/pki/jss/
# The source for this package was pulled from upstream's cvs. Use the
# following commands to generate the tarball:
# cvs -d :pserver:anonymous@cvs-mirror.mozilla.org:/cvsroot export -r JSS_4_2_5_RTM -d jss-4.2.5 -N mozilla/security/coreconf mozilla/security/jss
# tar -czvf jss-4.2.5.tar.gz jss-4.2.5
Source0:        %{name}-%{version}.tar.gz
Source1:        MPL-1.1.txt
Source2:        gpl.txt
Source3:        lgpl.txt
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  nspr-devel >= 4.6.99
BuildRequires:  nss-devel >= 3.12.0
BuildRequires:  java-devel >= 1.6.0
BuildRequires:  pkgconfig
# Force use of OpenJDK for development
BuildRequires:  java-devel-openjdk >= 1.6.0
Requires:       nss >= 3.12.0
# Urge use of OpenJDK for runtime
Requires:       java-1.6.0-openjdk

# don't use sun.net.www.protocol.http.HttpURLConnection.userAgent
Patch1:         jss-useragent.patch

%description
Java Security Services (JSS) is a java native interface which provides a bridge
for java-based applications to use native Network Security Services (NSS).
This only works with gcj. Other JREs require that JCE providers be signed.


%prep
%setup -q
%patch1 -p1

%build
[ -z "$JAVA_HOME" ] && export JAVA_HOME=%{_jvmdir}/java

%ifarch i386
JAVA_HOME=/usr/lib/jvm/java-1.6.0-openjdk
export JAVA_HOME
%endif

%ifarch x86_64
JAVA_HOME=/usr/lib/jvm/java-1.6.0-openjdk.x86_64
export JAVA_HOME
%endif

# Enable compiler optimizations and disable debugging code
BUILD_OPT=1
export BUILD_OPT

# Generate symbolic info for debuggers
XCFLAGS="-g $RPM_OPT_FLAGS"
export XCFLAGS

PKG_CONFIG_ALLOW_SYSTEM_LIBS=1
PKG_CONFIG_ALLOW_SYSTEM_CFLAGS=1

export PKG_CONFIG_ALLOW_SYSTEM_LIBS
export PKG_CONFIG_ALLOW_SYSTEM_CFLAGS

NSPR_INCLUDE_DIR=`/usr/bin/pkg-config --cflags-only-I nspr | sed 's/-I//'`
NSPR_LIB_DIR=`/usr/bin/pkg-config --libs-only-L nspr | sed 's/-L//'`

NSS_INCLUDE_DIR=`/usr/bin/pkg-config --cflags-only-I nss | sed 's/-I//'`
NSS_LIB_DIR=`/usr/bin/pkg-config --libs-only-L nss | sed 's/-L//'`

export NSPR_INCLUDE_DIR
export NSPR_LIB_DIR
export NSS_INCLUDE_DIR
export NSS_LIB_DIR

%ifarch x86_64 ppc64 ia64 s390x sparc64
USE_64=1
export USE_64
%endif

# The Makefile is not thread-safe
make -C mozilla/security/coreconf
make -C mozilla/security/jss

%install
rm -rf ${RPM_BUILD_ROOT} docdir

# Copy the license files here so we can include them in %doc
cp -p %{SOURCE1} .
cp -p %{SOURCE2} .
cp -p %{SOURCE3} .

# There is no install target so we'll do it by hand

# Version Definitions
%define major_version     $(echo "%{version}" | sed 's/[ .][0-9]*[ .][0-9]*//')
%define minor_version     $(echo "%{version}" | sed 's/^[0-9]*[ .]//' | sed 's/[ .][0-9]*//')
%define patch_version     $(echo "%{version}" | sed 's/^[0-9]*[ .][0-9]*[ .]//')

# FIXME - sign jss%{major_version}.jar. In order to use JSS as a JCE provider
# it needs to be signed with a Sun-issued certificate. Since we would need to
# make this certificate and private key public to provide reproducability in
# the rpm building we have to ship an unsigned jar.
#
# Instructions for getting a signing cert can be found here:
# http://java.sun.com/javase/6/docs/technotes/guides/security/crypto/HowToImplAProvider.html#Step61
#
# This signing is not required by every JVM. gcj ignores the signature and does
# not require one. The Sun and IBM JVMs both check and enforce the signature.
# Behavior of other JVMs is not known but they probably enforce the signature
# as well.
#
%define rpm_sign_exists %(test -x /usr/bin/rpm-sign && echo 1 || echo 0)
%if %{rpm_sign_exists}
#
# Use the restricted 'rpm-sign' executable to sign jars:
#
%define sign_jss_jar %(echo "rpm-sign --jarsign --key jcesigncert jss%{major_version}-%{version}.jar")
%else
#
# Use the 'jarsigner' executable to sign jars:
#
%define defined_jss_keystore %(test "%{?jss_keystore}" = "" && echo 0 || echo 1)
%if %{defined_jss_keystore}
%define defined_jss_password %(test "%{?jss_password}" = "" && echo 0 || echo 1)
%if %{defined_jss_password}
%define defined_jss_alias %(test "%{?jss_alias}" = "" && echo 0 || echo 1)
%if %{defined_jss_alias}
%define jarsigner_exists %(test -x /usr/bin/jarsigner && echo 1 || echo 0)
%if %{jarsigner_exists}
%define sign_jss_jar %(echo "jarsigner -keystore %{jss_keystore} -storepass %{jss_password} jss%{major_version}-%{version}.jar %{jss_alias}")
%define verify_jss_jar %(echo "jarsigner -verify -verbose jss%{major_version}-%{version}.jar %{jss_alias}")
%else
echo "Missing jarsigner executable!"
%endif
%else
echo "JSS alias is undefined!"
%endif
%else
echo "JSS password is undefined!"
%endif
%else
echo "JSS keystore is undefined!"
%endif
%endif

# jars
install -d -m 0755 ${RPM_BUILD_ROOT}%{_jnidir}
install -m 644 mozilla/dist/xpclass.jar ${RPM_BUILD_ROOT}%{_jnidir}/jss%{major_version}-%{version}.jar
pushd  ${RPM_BUILD_ROOT}%{_jnidir}
    %{?sign_jss_jar}
    %{?verify_jss_jar}
    ln -fs jss%{major_version}-%{version}.jar jss%{major_version}.jar
popd

# We have to use the name libjss%{major_version}.so because this is dynamically
# loaded by the jar file.
install -d -m 0755 ${RPM_BUILD_ROOT}%{_libdir}
install -m 0755 mozilla/dist/Linux*.OBJ/lib/libjss%{major_version}.so ${RPM_BUILD_ROOT}%{_libdir}/

%clean
rm -rf ${RPM_BUILD_ROOT}

# No ldconfig is required since this library is loaded by Java itself.
%files
%defattr(-,root,root,-)
%doc mozilla/security/jss/jss.html MPL-1.1.txt gpl.txt lgpl.txt
%{_jnidir}/*
%{_libdir}/lib*.so


%changelog
* Mon Nov 10 2008 Matthew Harmsen <mharmsen@redhat.com> 4.2.5-1%{?dist}
- Updated JSS version to 4.2.5.
- Updated BuildRequires for nspr-devel >= 4.6.99
- Updated BuildRequires for nss-devel >= 3.12.0
- Updated BuildRequires for java-devel >= 1.6.0
- Updated BuildRequires for pkgconfig
- Force BuildRequires to use java-devel-openjdk >= 1.6.0 (OpenJDK 1.6.0)
- Updated Requires for nss >= 3.12.0
- Updated Requires for java >= 1.6.0

* Fri Oct 12 2007 Margaret Lum <mlum@redhat.com> 4.2.4-41.el5idm
- Build with IBM JVM 1.4.2.  Rebuild.  Added LD_PRELOAD back in for 232224.
- Updated BuildRequires for java-1.4.2-ibm. 

* Tue Sep 04 2007 Margaret Lum <mlum@redhat.com> 4.2.4-37.el5idm
- Define JAVA_HOME for build_java.pl

* Thu Aug 30 2007 Margaret Lum <mlum@redhat.com> 4.2.4-36.el5idm
- Revert back to gcj 1.4.2 since 1.5 (IBM) compiled doesn't work with Marathon for DS

* Tue Aug 14 2007 Margaret Lum <mlum@redhat.com> 4.2.4-35.el5idm
- Removed extraneous copy of jss4.jar under /usr/libARCH/java

* Tue Aug 14 2007 Margaret Lum <mlum@redhat.com> 4.2.4-31.el5idm
- Create the libdir/java for xpclass.jar to be copied.

* Tue Aug 14 2007 Margaret Lum <mlum@redhat.com> 4.2.4-30.el5idm
- Disable signing until all dependencies are built.

* Tue Aug 14 2007 Margaret Lum <mlum@redhat.com> 4.2.4-29.el5idm
- Add pkgconfig to BuildRequires.

* Sun Jul 22 2007 Margaret Lum <mlum@redhat.com> 4.2.4-28.el5idm
- Using IBM JVM for now; requires LD_PRELOAD for bug 232224

* Sat Jul 21 2007 Margaret Lum <mlum@redhat.com> 4.2.4-27.el5idm
- Require java >= 1.5.0, since multiple jvms are tagged in buildroot

* Sat Jul 21 2007 Margaret Lum <mlum@redhat.com> 4.2.4-26.el5idm
- Latest import from Fedora, including rpmsigning of jar

* Thu May 24 2007 Rob Crittenden <rcritten@redhat.com> 4.2.4-6
- Use _jnidir macro instead of _javadir for the jar files. This will break
  multilib installs but adheres to the jpackage spec.

* Wed May 16 2007 Rob Crittenden <rcritten@redhat.com> 4.2.4-5
- Include the 3 license files
- Remove Requires for nss and nspr. These libraries have versioned symbols
  so BuildRequires is enough to set the minimum.
- Add sparc64 for the 64-bit list

* Mon May 14 2007 Rob Crittenden <rcritten@redhat.com> 4.2.4-4
- Included additional comments on jar signing and why ldconfig is not
  required.

* Thu May 10 2007 Rob Crittenden <rcritten@redhat.com> 4.2.4-3
- Added information on how to pull the source into a tar.gz

* Thu Mar 15 2007  Rob Crittenden <rcritten@redhat.com> 4.2.4-2
- Added RPM_OPT_FLAGS to XCFLAGS

- Added link to Sun JCE information
* Mon Feb 27 2007 Rob Crittenden <rcritten@redhat.com> 4.2.4-1
- Initial build
